package com.test.security;

import java.security.acl.Group;
import java.util.Map;

import javax.security.auth.Subject;
import javax.security.auth.callback.CallbackHandler;
import javax.security.auth.login.LoginException;

import org.jboss.security.SimpleGroup;
import org.jboss.security.auth.spi.UsernamePasswordLoginModule;

public class TestLoginModule extends UsernamePasswordLoginModule {

    public TestLoginModule() {
        super();
        System.out.println("Created test login module");
    }

    /**
     * Initialize this LoginModule.
     */
    @Override
    public void initialize(Subject subject, CallbackHandler callbackHandler,
            Map sharedState, Map options) {
        super.initialize(subject, callbackHandler, sharedState, options);
        
        System.out.println("Initialized " + subject);
        
    }

    /**
     * Get the expected password for the current username available via the
     * getUsername() method. This is called from within the login() method after
     * the CallbackHandler has returned the username and candidate password.
     * 
     * @return the valid password String
     */
    @Override
    protected String getUsersPassword() throws LoginException {
        System.out.println("Get user password");
        return "123";
    }

    /**
     * Execute the rolesQuery against the dsJndiName to obtain the roles for the
     * authenticated user.
     * 
     * @return Group[] containing the sets of roles
     */
    @Override
    protected Group[] getRoleSets() throws LoginException {
        
        System.out.println("Get rolesets for " + super.getUsername());
        
        Group secureUser = new SimpleGroup("Roles");
        try {
            secureUser.addMember(this.createIdentity("SecureUser"));
        } catch (Exception e) {
            log.error("Failed to create principal: SecureUser", e);
        }
        Group[] roleSets = new Group[] { secureUser };
        
        TestLoginModule m = this;
        
        return roleSets;
    }

    /*
     * (non-Javadoc)
     * @see
     * org.jboss.security.auth.spi.UsernamePasswordLoginModule#validatePassword
     * (java.lang.String, java.lang.String)
     */
    @Override
    protected boolean validatePassword(String inputPassword,
            String expectedPassword) {
        System.out.println("input pwd: " + inputPassword);
        System.out.println("expected pwd: " + expectedPassword);
        return true;
    }
}
